import requests
import re
import argparse
import os
import subprocess


def is_replace(connector_name, compatible_version):
    compatible_version = compatible_version.strip()

    if compatible_version == 'ALL':
        return True

    if compatible_version == 'NULL':
        return False

    if not re.compile(r"[0-9]+.[0-9]+.[0-9]+$").match(compatible_version):
        raise Exception('Incorrect Compatible Version Information')
    response = requests.get('https://localhost:9595/integration/connectors/?format=json', verify=False,
                             headers={'Content-Type': 'application/json'})
    if response.ok:
        connectors = response.json()['data']
        compatible_version_map = tuple(map(int, (compatible_version.split("."))))
        for connector in connectors:
            name = connector['name']
            if name == connector_name:
                version = connector['version']
                if tuple(map(int, (version.split(".")))) < compatible_version_map:
                    return False
        return True
    raise Exception('Failed to validate against installed connectors')


def import_connector(connector_name, compatible_version):
    # create request with file
    python_dir = '/opt/cyops-integrations/.env/bin/python'
    management_script = '/opt/cyops-integrations/integrations/manage.py'
    command_name = 'import_connectors_from_path'
    conector_path = '/opt/cyops-connector-' + connector_name + '/' + connector_name+ '.tgz'
    rpm_installed = True
    
    command = ['sudo', '-u', 'nginx', python_dir, management_script, command_name, '--path', conector_path, '--name', connector_name, 
               '--compversion', compatible_version]
    subprocess.Popen(command)


if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='Import Connectors')
    parser.add_argument('--name', type=str, help='Name of the Connector to Import', required=True)
    parser.add_argument('--compatibility', type=str, help='Oldest Compatible Version Of the Connector', required=True)
    args = parser.parse_args()
    os.environ['NO_PROXY'] = 'localhost'
    import_connector(args.name, args.compatibility)
